@@ -1,5 +1,5 @@
 package DBIx::Class::Helper::ResultSet::DateMethods1;
-$DBIx::Class::Helper::ResultSet::DateMethods1::VERSION = '2.023006';
+$DBIx::Class::Helper::ResultSet::DateMethods1::VERSION = '2.024000';
 # ABSTRACT: Work with dates in your RDBMS nicely
 
 use strict;
@@ -291,10 +291,8 @@ sub _introspector {
 
             my ($sql, @args) = @$date_sql;
 
-            $sql = "TO_TIMESTAMP($sql)"
-                if $part =~ /second|minute|hour/;
             return [
-               "EXTRACT($part_map{$part} FROM $sql)", @args
+               "EXTRACT($part_map{$part} FROM TO_TIMESTAMP($sql))", @args
             ]
          }
       });
@@ -312,7 +310,7 @@ sub _introspector {
             die "unknown unit $unit" unless $diff_part_map{$unit};
 
             return [
-               "($d_sql + NUMTODSINTERVAL($a_sql, ?))",
+               "(TO_TIMESTAMP($d_sql) + NUMTODSINTERVAL($a_sql, ?))",
                @d_args, @a_args, $diff_part_map{$unit}
             ];
          }
